pub struct ModelHandle(/* private fields */);Trait Implementations
Sourceimpl Clone for ModelHandle
impl Clone for ModelHandle
Sourcefn clone(&self) -> ModelHandle
fn clone(&self) -> ModelHandle
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ModelHandle
Sourceimpl Debug for ModelHandle
impl Debug for ModelHandle
Sourceimpl Default for ModelHandle
impl Default for ModelHandle
Sourcefn default() -> ModelHandle
fn default() -> ModelHandle
Returns the “default value” for a type. Read more
impl Eq for ModelHandle
Sourceimpl From<KeyData> for ModelHandle
impl From<KeyData> for ModelHandle
Sourceimpl Hash for ModelHandle
impl Hash for ModelHandle
Sourceimpl Key for ModelHandle
impl Key for ModelHandle
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for ModelHandle
impl Ord for ModelHandle
Sourcefn cmp(&self, other: &ModelHandle) -> Ordering
fn cmp(&self, other: &ModelHandle) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ModelHandle
impl PartialEq for ModelHandle
Sourcefn eq(&self, other: &ModelHandle) -> bool
fn eq(&self, other: &ModelHandle) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ModelHandle
impl PartialOrd for ModelHandle
impl StructuralPartialEq for ModelHandle