pub struct TextureHandle(/* private fields */);Trait Implementations
Sourceimpl Clone for TextureHandle
impl Clone for TextureHandle
Sourcefn clone(&self) -> TextureHandle
fn clone(&self) -> TextureHandle
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TextureHandle
impl Debug for TextureHandle
Sourceimpl Default for TextureHandle
impl Default for TextureHandle
Sourcefn default() -> TextureHandle
fn default() -> TextureHandle
Returns the “default value” for a type. Read more
Sourceimpl From<KeyData> for TextureHandle
impl From<KeyData> for TextureHandle
Sourceimpl Hash for TextureHandle
impl Hash for TextureHandle
Sourceimpl Key for TextureHandle
impl Key for TextureHandle
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for TextureHandle
impl Ord for TextureHandle
Sourcefn cmp(&self, other: &TextureHandle) -> Ordering
fn cmp(&self, other: &TextureHandle) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TextureHandle
impl PartialEq for TextureHandle
Sourcefn eq(&self, other: &TextureHandle) -> bool
fn eq(&self, other: &TextureHandle) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for TextureHandle
impl PartialOrd for TextureHandle
impl Copy for TextureHandle
impl Eq for TextureHandle
impl StructuralPartialEq for TextureHandle