pub struct ClippingPlaneKey(/* private fields */);Trait Implementations
Sourceimpl Clone for ClippingPlaneKey
impl Clone for ClippingPlaneKey
Sourcefn clone(&self) -> ClippingPlaneKey
fn clone(&self) -> ClippingPlaneKey
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ClippingPlaneKey
impl Debug for ClippingPlaneKey
Sourceimpl Default for ClippingPlaneKey
impl Default for ClippingPlaneKey
Sourcefn default() -> ClippingPlaneKey
fn default() -> ClippingPlaneKey
Returns the “default value” for a type. Read more
Sourceimpl From<KeyData> for ClippingPlaneKey
impl From<KeyData> for ClippingPlaneKey
Sourceimpl Hash for ClippingPlaneKey
impl Hash for ClippingPlaneKey
Sourceimpl Key for ClippingPlaneKey
impl Key for ClippingPlaneKey
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for ClippingPlaneKey
impl Ord for ClippingPlaneKey
Sourcefn cmp(&self, other: &ClippingPlaneKey) -> Ordering
fn cmp(&self, other: &ClippingPlaneKey) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ClippingPlaneKey
impl PartialEq for ClippingPlaneKey
Sourcefn eq(&self, other: &ClippingPlaneKey) -> bool
fn eq(&self, other: &ClippingPlaneKey) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ClippingPlaneKey
impl PartialOrd for ClippingPlaneKey
impl Copy for ClippingPlaneKey
impl Eq for ClippingPlaneKey
impl StructuralPartialEq for ClippingPlaneKey