pub struct ReflectionProbeKey(/* private fields */);Trait Implementations
Sourceimpl Clone for ReflectionProbeKey
impl Clone for ReflectionProbeKey
Sourcefn clone(&self) -> ReflectionProbeKey
fn clone(&self) -> ReflectionProbeKey
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ReflectionProbeKey
Sourceimpl Debug for ReflectionProbeKey
impl Debug for ReflectionProbeKey
Sourceimpl Default for ReflectionProbeKey
impl Default for ReflectionProbeKey
Sourcefn default() -> ReflectionProbeKey
fn default() -> ReflectionProbeKey
Returns the “default value” for a type. Read more
impl Eq for ReflectionProbeKey
Sourceimpl From<KeyData> for ReflectionProbeKey
impl From<KeyData> for ReflectionProbeKey
Sourceimpl Hash for ReflectionProbeKey
impl Hash for ReflectionProbeKey
Sourceimpl Key for ReflectionProbeKey
impl Key for ReflectionProbeKey
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for ReflectionProbeKey
impl Ord for ReflectionProbeKey
Sourcefn cmp(&self, other: &ReflectionProbeKey) -> Ordering
fn cmp(&self, other: &ReflectionProbeKey) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ReflectionProbeKey
impl PartialEq for ReflectionProbeKey
Sourceimpl PartialOrd for ReflectionProbeKey
impl PartialOrd for ReflectionProbeKey
impl StructuralPartialEq for ReflectionProbeKey